import { FastifyError } from 'fastify';

export const InvalidPayload = () =>
    ({
        code: '400',
        statusCode: 400,
        name: 'InvalidPayload',
        message:
            "Payload type is invalid. Did you forget to set a proper 'Content-Type'?",
    }) as FastifyError;

export const ValidationError = (err?: string) =>
    ({
        code: '400',
        statusCode: 400,
        name: 'ValidationError',
        message: err
            ? 'The schema does not match'
            : 'The schema does not match: ' + err,
    }) as FastifyError;

export const InvalidAuthorization = () =>
    ({
        code: '401',
        statusCode: 401,
        name: 'InvalidAuthorization',
        message: 'Provided authorization credentials are invalid',
    }) as FastifyError;

export const QuotaExceeded = () =>
    ({
        code: '422',
        statusCode: 422,
        name: 'QuotaExceeded',
        message:
            'Your quota has exceeded. Please delete some files to proceed.',
    }) as FastifyError;

export const NotFoundError = () =>
    ({
        code: '404',
        statusCode: 404,
        name: 'NotFound',
        message:
            'The requested resource has never existed, deleted or has a different name or path.',
    }) as FastifyError;
